summaryrefslogtreecommitdiffstats
path: root/sys/powerpc
diff options
context:
space:
mode:
authorjhb <jhb@FreeBSD.org>2001-01-24 21:59:25 +0000
committerjhb <jhb@FreeBSD.org>2001-01-24 21:59:25 +0000
commitaf00dc8eef26d6f9d2b9d3cd92429a0db97e0b3c (patch)
tree1a65f27d40bfb7ed1d2518d205618e42ea64e92b /sys/powerpc
parent222035d6b123a02eab80f14e5165f2cf38dfda82 (diff)
downloadFreeBSD-src-af00dc8eef26d6f9d2b9d3cd92429a0db97e0b3c.zip
FreeBSD-src-af00dc8eef26d6f9d2b9d3cd92429a0db97e0b3c.tar.gz
- Change fork_exit() to take a pointer to a trapframe as its 3rd argument
instead of a trapframe directly. (Requested by bde.) - Convert the alpha switch_trampoline to call fork_exit() and use the MI fork_return() instead of child_return(). - Axe child_return().
Diffstat (limited to 'sys/powerpc')
-rw-r--r--sys/powerpc/aim/vm_machdep.c4
-rw-r--r--sys/powerpc/powerpc/vm_machdep.c4
2 files changed, 4 insertions, 4 deletions
diff --git a/sys/powerpc/aim/vm_machdep.c b/sys/powerpc/aim/vm_machdep.c
index c60f971..c5c8cd5 100644
--- a/sys/powerpc/aim/vm_machdep.c
+++ b/sys/powerpc/aim/vm_machdep.c
@@ -196,7 +196,7 @@ cpu_fork(p1, p2, flags)
p2tf->tf_regs[FRAME_A4] = 1; /* is child (FreeBSD) */
/*
* Arrange for continuation at child_return(), which
* will return to exception_return(). Note that the child
* process doesn't stay in the kernel for long!
*
@@ -204,7 +204,7 @@ cpu_fork(p1, p2, flags)
*/
up->u_pcb.pcb_hw.apcb_ksp = (u_int64_t)p2tf;
up->u_pcb.pcb_context[0] =
- (u_int64_t)child_return; /* s0: pc */
+ (u_int64_t)fork_return; /* s0: pc */
up->u_pcb.pcb_context[1] =
(u_int64_t)exception_return; /* s1: ra */
up->u_pcb.pcb_context[2] = (u_long) p2; /* s2: a0 */
@@ -196,7 +196,7 @@ cpu_fork(p1, p2, flags)
p2tf->tf_regs[FRAME_A4] = 1; /* is child (FreeBSD) */
/*
- * Arrange for continuation at child_return(), which
+ * Arrange for continuation at fork_return(), which
* will return to exception_return(). Note that the child
* process doesn't stay in the kernel for long!
diff --git a/sys/powerpc/powerpc/vm_machdep.c b/sys/powerpc/powerpc/vm_machdep.c
index c60f971..c5c8cd5 100644
--- a/sys/powerpc/powerpc/vm_machdep.c
+++ b/sys/powerpc/powerpc/vm_machdep.c
@@ -196,7 +196,7 @@ cpu_fork(p1, p2, flags)
p2tf->tf_regs[FRAME_A4] = 1; /* is child (FreeBSD) */
/*
* Arrange for continuation at child_return(), which
* will return to exception_return(). Note that the child
* process doesn't stay in the kernel for long!
*
@@ -204,7 +204,7 @@ cpu_fork(p1, p2, flags)
*/
up->u_pcb.pcb_hw.apcb_ksp = (u_int64_t)p2tf;
up->u_pcb.pcb_context[0] =
- (u_int64_t)child_return; /* s0: pc */
+ (u_int64_t)fork_return; /* s0: pc */
up->u_pcb.pcb_context[1] =
(u_int64_t)exception_return; /* s1: ra */
up->u_pcb.pcb_context[2] = (u_long) p2; /* s2: a0 */
@@ -196,7 +196,7 @@ cpu_fork(p1, p2, flags)
p2tf->tf_regs[FRAME_A4] = 1; /* is child (FreeBSD) */
/*
- * Arrange for continuation at child_return(), which
+ * Arrange for continuation at fork_return(), which
* will return to exception_return(). Note that the child
* process doesn't stay in the kernel for long!
OpenPOWER on IntegriCloud